
# Type: capable of


holds between a physical entity and process or function, where the continuant alone has the ability to carry out the process or function.

URI: [biolink:capable_of](https://w3id.org/biolink/vocab/capable_of)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [actively involved in](actively_involved_in.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002215 |
| **In Subsets:** | | translator_minimal |

